Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(240)

Unified Diff: media/formats/mp2t/descriptors.h

Issue 2783703002: Declare intent to use sample-aes later in the stream. (Closed)
Patch Set: tweak needed for flush Created 3 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/formats/mp2t/descriptors.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/formats/mp2t/descriptors.h
diff --git a/media/formats/mp2t/descriptors.h b/media/formats/mp2t/descriptors.h
index cfbca63578c7b5ebe00dadb193cb8cd6dff65638..6737d09a6287502bab05d5a148b4416d6cd024a3 100644
--- a/media/formats/mp2t/descriptors.h
+++ b/media/formats/mp2t/descriptors.h
@@ -13,6 +13,7 @@
namespace media {
class BitReader;
+class EncryptionScheme;
namespace mp2t {
@@ -46,9 +47,11 @@ class Descriptors {
// Indicates whether a CA descriptor is present, and if so, whether it is
// of the type defined by ISO/IEC 23001-9:2014 (i.e. with a specific
- // system_id value and layout of the private_data). If so, the |ca_pid| and
- // |pssh_pid| are populated with the contents of the descriptor.
- bool HasCADescriptorCenc(int* ca_pid, int* pssh_pid) const;
+ // system_id value and layout of the private_data). If so, the |ca_pid|,
+ // |pssh_pid| and |scheme| are populated with the contents of the descriptor.
+ bool HasCADescriptorCenc(int* ca_pid,
+ int* pssh_pid,
+ EncryptionScheme* scheme) const;
// Indicates whether a Private Data Indicator descriptor is present with a
// particular |value|.
« no previous file with comments | « no previous file | media/formats/mp2t/descriptors.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698